@@ -117,9 +117,6 @@ namespace ompl
             addPlannerProgressProperty("best cost DOUBLE", [this] { return bestCostProgressProperty(); });
             addPlannerProgressProperty("number of segments in solution path INTEGER",
                                        [this] { return bestLengthProgressProperty(); });
-            addPlannerProgressProperty("current free states INTEGER", [this] { return currentFreeProgressProperty(); });
-            addPlannerProgressProperty("current graph vertices INTEGER",
-                                       [this] { return currentVertexProgressProperty(); });
             addPlannerProgressProperty("state collision checks INTEGER",
                                        [this] { return stateCollisionCheckProgressProperty(); });
             addPlannerProgressProperty("edge collision checks INTEGER",
@@ -129,10 +126,6 @@ namespace ompl
 
             // Extra progress info that aren't necessary for every day use. Uncomment if desired.
             /*
-            addPlannerProgressProperty("vertex queue size INTEGER", [this]
-                                       {
-                                           return vertexQueueSizeProgressProperty();
-                                       });
             addPlannerProgressProperty("edge queue size INTEGER", [this]
                                        {
                                            return edgeQueueSizeProgressProperty();
@@ -661,14 +654,10 @@ namespace ompl
 
                 // Count the number of samples that could be pruned.
                 auto samples = graphPtr_->getCopyOfSamples();
-                unsigned int numSamplesThatCouldBePruned(0u);
-                for (const auto &sample : samples)
-                {
-                    if (graphPtr_->canSampleBePruned(sample))
-                    {
-                        ++numSamplesThatCouldBePruned;
-                    }
-                }
+                auto numSamplesThatCouldBePruned =
+                    std::count_if(samples.begin(), samples.end(), [this](const auto& sample){
+                        return graphPtr_->canSampleBePruned(sample);
+                    });
 
                 // Only prune if the decrease in number of samples and the associated decrease in nearest neighbour
                 // lookup cost justifies the cost of pruning. There has to be a way to make this more formal, and less
@@ -1336,7 +1325,7 @@ namespace ompl
 
         std::string BITstar::bestCostProgressProperty() const
         {
-            return ompl::toString(this->bestCost().value());
+            return ompl::toString(bestCost_.value());
         }
 
         std::string BITstar::bestLengthProgressProperty() const
@@ -1344,16 +1333,6 @@ namespace ompl
             return std::to_string(bestLength_);
         }
 
-        std::string BITstar::currentFreeProgressProperty() const
-        {
-            return std::to_string(graphPtr_->numSamples());
-        }
-
-        std::string BITstar::currentVertexProgressProperty() const
-        {
-            return std::to_string(graphPtr_->numVertices());
-        }
-
         std::string BITstar::edgeQueueSizeProgressProperty() const
         {
             return std::to_string(queuePtr_->numEdges());
@@ -1361,12 +1340,12 @@ namespace ompl
 
         std::string BITstar::iterationProgressProperty() const
         {
-            return std::to_string(this->numIterations());
+            return std::to_string(numIterations_);
         }
 
         std::string BITstar::batchesProgressProperty() const
         {
-            return std::to_string(this->numBatches());
+            return std::to_string(numBatches_);
         }
 
         std::string BITstar::pruningProgressProperty() const
