@@ -148,7 +148,10 @@ ompl::geometric::LazyPRM::LazyPRM(const base::PlannerData &data, bool starStrate
     }
 }
 
-ompl::geometric::LazyPRM::~LazyPRM() = default;
+ompl::geometric::LazyPRM::~LazyPRM()
+{
+    clear();
+};
 
 void ompl::geometric::LazyPRM::setup()
 {
@@ -390,7 +393,7 @@ ompl::base::PlannerStatus ompl::geometric::LazyPRM::solve(const base::PlannerTer
             do
             {
                 solution = constructSolution(startV, goalV);
-            } while (!solution && vertexComponentProperty_[startV] == vertexComponentProperty_[goalV]);
+            } while (!solution && vertexComponentProperty_[startV] == vertexComponentProperty_[goalV] && !ptc);
             if (solution)
             {
                 someSolutionFound = true;
