@@ -64,6 +64,15 @@ ompl::geometric::PathGeometric::PathGeometric(const base::SpaceInformationPtr &s
     states_[1] = si_->cloneState(state2);
 }
 
+ompl::geometric::PathGeometric::PathGeometric(const base::SpaceInformationPtr &si, std::vector<const base::State *> &states)
+  : base::Path(si)
+{
+    for(unsigned int k = 0; k < states.size(); k++)
+    {
+        this->append(states.at(k));
+    }
+}
+
 ompl::geometric::PathGeometric &ompl::geometric::PathGeometric::operator=(const PathGeometric &other)
 {
     if (this != &other)
